@@ -86,7 +86,7 @@
 #define KWALLET_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWALLET_NO_DEPRECATED
-#  define KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55100
+#  define KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KWALLET_NO_DEPRECATED_WARNINGS
 #  define KWALLET_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWALLET_DEPRECATED_WARNINGS_SINCE KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWALLET_DEPRECATED_WARNINGS_SINCE 0x55100
+#    define KWALLET_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -118,5 +118,12 @@
 #define KWALLET_DEPRECATED_VERSION_5(minor, text)      KWALLET_DEPRECATED_VERSION_5_##minor(text)
 #define KWALLET_DEPRECATED_VERSION(major, minor, text) KWALLET_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KWALLET_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWALLET_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KWALLET_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KWALLET_DEPRECATED_VERSION(major, minor, text)
+#  define KWALLET_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWALLET_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KWALLET_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KWALLET_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KWALLET_EXPORT_H */
